# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext as _


class Category(models.Model):
    name = models.CharField(_('Category name'), max_length=128)
    slug = models.SlugField(max_length=128, unique=True,
                            help_text=_("Used to build the entry's URL."))

    class Meta:
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')
            
    def __unicode__(self):
        return self.name
    
class Portfolio(models.Model):
    title = models.CharField(_('Title'), max_length=128)
    description = models.TextField(_('Description'), null=True, blank=True)
    slug = models.SlugField(max_length=128, unique=True,
                            help_text=_("Used to build the entry's URL."))
    date_added = models.DateTimeField(auto_now_add=True)
    date_completed = models.DateTimeField(verbose_name=_('Completion date'), 
                                          null=True, blank=True )
    image = models.ImageField(verbose_name=_('Image'),
                                      upload_to="portfolio", 
                                      help_text=_('Used for illustration.'),
                                      null=True, blank=True)
    categories = models.ManyToManyField(Category,
                                        verbose_name=_('Select categories'), 
                                        null=True, blank=True)

    class Meta:
        verbose_name = _('Portfolio item')
        verbose_name_plural = _('Portfolio items')
        ordering = ['-date_completed']
    
    def __unicode__(self):
        return self.title    
    
    @models.permalink
    def get_absolute_url(self):
        return ("portfolio_detail", (), {'item_slug': self.slug })
